+++
title = 'Self-built UV exposure unit (LED)'
date = 2025-04-14T08:11:20+02:00
draft = false
toc = true
cover = 'cover.jpg'
+++


If you've been around the (electronics) DIY scene for a while, at some point you can't avoid circuit boards (printed circuit boards/PCBs). The main advantages over soldering circuits by hand on perforated or strip-grid boards are that they are easier to replicate (once designed a circuit can theoretically be produced as often as you like) and that space can be used more efficiently (a board is almost always smaller than a soldered perforated grid board with the same circuit). Ultimately, devices with circuit boards also simply look more professional. There are certainly more advantages (and of course also disadvantages!), but I will not list them here for the sake of simplicity.

Nowadays, it is very easy to have (self-)created circuit board designs manufactured, with relevant offers from China you pay no more than €5 for a simple circuit board with 2 sides. However, the price does not include the shipping costs and the time you have to wait for your PCBs. If you are not planning to produce several different designs a year, or only need a special circuit board once, you are well served with such offers. However, if you often need custom-made products, it can quickly become lucrative (even with the Chinese offers) to bring the production in-house.  At the end of the day, it's fun and at least gives you the feeling of a little independence to make your own circuit boards!

So after dreaming of making my own circuit boards for some time, I have now gone one step further in the realization. There are various ways to produce printed circuit boards yourself. The cheapest method is probably exposing a blank PCB with a photopositive coating and then developing and finally etching the exposed areas. Building the etching device myself seemed too tricky, so I decided to buy a used [Ätzgerät 1 from pro-ma](https://gie-tec.de/produkt/aetzgeraete-fuer-platinen/), which was very cheap at €50. But what you can certainly build yourself is the **UV exposure unit**. There are different approaches here, I just want to share mine here (see e.g. [here](https://www.all4hardware4u.de/platinenherstellung/belichtung/belichtungsgeraet-mit-uv-leds/) or also [here](http://www.fdm-ware.de/UV-Led/) for the models where I found inspiration)!

So enough of the introduction, here's the really important stuff!


## The housing {id=the-housing}

For the housing, I built a simple box from MDF boards with an additional small section at the front, where the control electronics will be located later.

{{< figure src="housing-raw-finished.jpg" alt="This picture would show the finished housing with acrylic glass pane and some loose components." caption="The finished housing with acrylic glass pane" >}}

In order for the UV light to reach the coated circuit board, the holder must be transparent. An acrylic glass pane does the job here. Important here: this **must** be UV-permeable, which is not necessarily the case with panes for the garden area! DIY store staff were unable to help in my case (it's a very specific requirement ;), but thanks to the internet you can find out more here. Sometimes it helps to look on the website of the DIY store of your choice for UV-permeable acrylic glass panes.

This pane must have a certain distance to the LEDs so that the light from the LEDs can be distributed evenly. You can of course calculate a perfect distance at - using the beam angle of the LEDs and the distance between the individual LEDs. However, I decided to use the simpler (and sometimes very inaccurate) rule of thumb here - but it worked.

{{< figure src="collage-plans.png" alt="This picture shows sketches for the individual sides of the wooden box" caption="Sketches of the box" >}}


## The LEDs {id=the-leds}

UV LEDs are quite easy to obtain from electronics suppliers. For this DIY project, I decided to use 48 LEDs in 6 rows of 8 LEDs each on two 160x100mm perforated grid boards (yes, a strip grid is also possible and would have been easier :). Since UV LEDs have an operating voltage of about 3.0 to 3.3V and I wanted to use a 12V power supply, you need a resistor of 470 Ohm for each LED, which drops about 9V at 20mA (there are several good tutorials on the Internet for calculating LED series resistors).

As far as the exposure time is concerned, see below in the section [“The practical part - Exposure time”](#exposure-time).

{{< figure src="led-distribution.png" alt="Links: Sketch of the distribution of the LEDs, right: view of the LEDs from above" caption="left: Sketch of the distribution of the LEDs; right: view of the LEDs from above" >}}


## The lacquering {id=the-lacquering}

Chrome-effect paint was the paint of choice for the exposure area. So, I masked everything except for the exposure area (and of course 
the LEDs!) and painted it several times according to the instructions on the spray can and left it to dry overnight.

{{< figure src="masked_for_painting.jpg" alt="Picture of the box masked for painting" caption="Box is masked, about to be painted!" >}}

{{< figure src="painted_inside.jpg" alt="Picture of the inside of the painted box" caption="It's shiny!" >}}


## The control unit {id=the-control-unit}

Here I was faced with a choice: install a simple switch or a more complex logic with a timer function? The idea of the built-in timer seemed appealing - finally programming something hardware-related again. So I assembled a breadboard (perhaps the last one ever?!) with a Raspberry Pi Pico, relays, a connection for an LCD display and some control elements, programmed a small interface with my existing libraries and the electronics were ready! To be installed in the housing, it still needed a cover. All the necessary information can be found in the corresponding [git repository](https://git.privacynerd.de/BlueFox/uv-belichter-software)!

{{< figure src="controller-on-dividing-wall.jpg" alt="Picture of the control unit" caption="The control unit" >}}

{{< figure src="front-panel.jpg" alt="Image of the front panel with the LCD and control elements in operation" caption="Front panel with LCD and control elements in operation" >}}


## The practical part - Exposure time {id=exposure-time}

So what does it look like in practice - the crucial question at the end. I would like to say that this is my first experience with manual PCB production. I used a simple blinky circuit (which was also my first completely self-made PCB design) for the tests.

{{< figure src="blinky-test-pcb.png" alt="Side-by-side view of the printed circuit and the view on the computer with all layers" caption="The test object..." >}}

So, my first experiences with the self-built exposure unit were mixed. The first attempt with 3 minutes exposure time went somewhat wrong. Specifically, no contours were visible even after 10-20 minutes in the developer at room temperature, and nothing happened even after 20-30 minutes etching. The second attempt was more promising, after 30 minutes of exposure the first contours could be seen after about 15 minutes of development, which actually disappeared during etching. After a few more attempts, I finally came up with the idea of working with two overlapping films instead of one, which meant that much less light came through the printed areas. The results were suddenly improving, and after a short time the circuit board was of sufficient quality for the circuit to function! 

{{< figure src="first-diy-pcbs.jpg" alt="Collage of the first manufacturing attempts up to the first functional PCB" caption="...and the results" >}}

So: The exposure time for successful results is between 40 and 45 minutes. Admittedly, that's quite a long time, but it's sufficient for my first attempts and more than acceptable considering the price of a finished exposure unit (which can easily run into the hundreds) (the exposure unit costs around €30-50 in total - and building it was a lot of fun!). For shorter exposure times, I am considering increasing the number of LEDs afterwards. But that's a story for another time.
